@@ -22,6 +22,18 @@
 #
 ########################################################################################################################
 
+"""
+**laygo2.object.grid** module contains classes that implement abstract coordinate systems that are interacting with technology-specific physical coordinate systems.
+
+laygo2 implements the layout designs based on the abstract coordinate system.
+
+.. image:: ../assets/img/user_guide_grid.png
+
+
+
+Check the following links for the details of component methods and classes.
+"""
+
 from .core import *
 from .routing import *
 from .placement import *
